@@ -18,16 +18,29 @@ import { MDFileMeta } from '@dts/common/fsal'
 
 export default class FilePathFindMetaData extends ZettlrCommand {
   constructor (app: any) {
-    super(app, ['file-find-and-return-meta-data'])
+    super(app, [ 'find-exact', 'file-find-and-return-meta-data' ])
   }
 
   /**
-      * Removes a file.
-      * @param {String} evt The event name
-      * @param  {Object} arg the parameters of the file to be deleted
-      * @return {Boolean} Whether the file was successfully deleted.
-      */
-  async run (evt: string, arg: any): Promise<any> {
+   * This command serves two purposes: For the MarkdownEditor component, it
+   * returns an easy to consume metadata object, and for the GraphView it offers
+   * a convenient access to the internal link resolution engine to resolve links
+   *
+   * @param   {string}                         evt  The event
+   * @param   {arg}                            arg  The argument, should be a query string
+   *
+   * @return  {MDFileMeta|undefined|string[]}       Returns a MetaDescriptor, undefined, or an array
+   */
+  async run (evt: string, arg: any): Promise<MDFileMeta|undefined|any[]> {
+    // Quick'n'dirty command to return the Meta descriptor for the given query
+    if (evt === 'find-exact') {
+      const descriptor = this._app.fsal.findExact(arg)
+      if (descriptor === undefined) {
+        return undefined
+      }
+      return this._app.fsal.getMetadataFor(descriptor) as MDFileMeta
+    }
+
     const file = this._app.fsal.findExact(arg)
     if (file !== undefined) {
       const metaData = await this._app.fsal.getFileContents(file) as MDFileMeta
@@ -40,7 +53,8 @@ export default class FilePathFindMetaData extends ZettlrCommand {
 
       return ([ title, content, wordCount, metaData.modtime ])
     }
+
     // We can't find it, so return Not Found
-    return null
+    return undefined
   }
 }
