@@ -11,15 +11,16 @@
  * END HEADER
  */
 
+import LogProvider from '@providers/log'
 import { protocol } from 'electron'
 
-export default function registerCustomProtocols (): void {
+export default function registerCustomProtocols (logger: LogProvider): void {
   // Make it possible to safely load external files
   // In order to load files, the 'safe-file' protocol has to be used instead of 'file'
   // https://stackoverflow.com/a/61623585/873661
   const protocolName = 'safe-file'
 
-  global.log.info(`Registering custom protocol ${protocolName}`)
+  logger.info(`Registering custom protocol ${protocolName}`)
   protocol.registerFileProtocol(protocolName, (request, callback) => {
     const url = request.url.replace(`${protocolName}://`, '')
     try {
@@ -30,7 +31,7 @@ export default function registerCustomProtocols (): void {
         headers: { 'Cache-control': 'no-store', 'pragma': 'no-cache' }
       })
     } catch (err: any) {
-      global.log.error(`Error loading external file: ${err.message as string}`, err)
+      logger.error(`Error loading external file: ${err.message as string}`, err)
     }
   })
 }
