@@ -13,15 +13,12 @@
  * END HEADER
  */
 
-import { mdFileExtensions } from '@common/get-file-extensions'
+import { mdFileExtensions } from '@providers/fsal/util/valid-file-extensions'
 import makeValidUri from '@common/util/make-valid-uri'
 import CodeMirror from 'codemirror'
-import { IpcRenderer } from 'electron'
-import { PlatformPath } from '@dts/renderer/path'
 
-const path: PlatformPath = (window as any).path
-
-const ipcRenderer: IpcRenderer = (window as any).ipc
+const path = window.path
+const ipcRenderer = window.ipc
 
 const VALID_FILETYPES = mdFileExtensions(true)
 
@@ -49,7 +46,7 @@ export default function (url: string, cm: CodeMirror.Editor): void {
     }
   } else if (url.startsWith('.')) {
     // We are definitely dealing with a relative URL. So let's resolve it
-    const absPath = path.resolve(url, base)
+    const absPath = path.resolve(base, url)
     window.location.assign(`safe-file://${absPath}`)
   } else if (url.startsWith('/') || url.startsWith('\\')) {
     // We are definitely dealing with an absolute URL.
@@ -62,6 +59,7 @@ export default function (url: string, cm: CodeMirror.Editor): void {
     // e.g., file://./relative.md will not throw an error albeit
     // we need to convert it to absolute.
     let validURI = makeValidUri(url, base)
+    console.log(validURI)
 
     // Now we have a valid link. Finally, let's check if we can open the file
     // internally, without having to switch to an external program.
