@@ -74,6 +74,17 @@ export default function (): any {
           model: 'attachmentExtensions'
         }
       ],
+      [
+        {
+          type: 'radio',
+          model: 'system.zoomBehavior',
+          label: trans('dialog.preferences.zoom_behavior.label'),
+          options: {
+            'gui': trans('dialog.preferences.zoom_behavior.gui'),
+            'editor': trans('dialog.preferences.zoom_behavior.editor')
+          }
+        }
+      ],
       [
         {
           type: 'list',
