@@ -19,7 +19,7 @@ import App from './App.vue'
 import windowRegister from '@common/modules/window-register'
 import { CodeFileMeta, MDFileMeta } from '@dts/common/fsal'
 
-const ipcRenderer = (window as any).ipc as Electron.IpcRenderer
+const ipcRenderer = window.ipc
 
 // The first thing we have to do is run the window controller
 windowRegister()
@@ -38,7 +38,7 @@ ipcRenderer.on('config-provider', (event, message) => {
   if (command === 'update') {
     const { payload } = message
     if (payload === 'editor.fontSize') {
-      app.$data.fontSize = global.config.get('editor.fontSize')
+      app.$data.fontSize = window.config.get('editor.fontSize')
     }
   }
 })
@@ -73,7 +73,7 @@ if (filePath === null) {
         app.$data.modified = file.modified
         app.$data.content = file.content
         // Set the correct font size
-        app.$data.fontSize = global.config.get('editor.fontSize')
+        app.$data.fontSize = window.config.get('editor.fontSize')
       }).catch((e) => {
         console.error(e)
       })
